#
# spec file for package tree-sitter-ruby
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         _name ruby
Name:           tree-sitter-ruby
Version:        0.23.1
Release:        1.1
Summary:        Ruby grammar for tree-sitter
License:        MIT
URL:            https://github.com/tree-sitter/tree-sitter-ruby
Source0:        %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  tree-sitter
%treesitter_grammars %{_name}

%description
%{summary}.

%prep
%autosetup

%build
%treesitter_configure
%treesitter_build

%install
%treesitter_install
%treesitter_devel_install

#neovim stuff
install -d %{buildroot}%{_libdir}/tree_sitter
ln -s %{_libdir}/lib%{name}.so %{buildroot}%{_libdir}/tree_sitter/%{_name}.so

%files
%license LICENSE
%treesitter_files
%{_libdir}/tree_sitter/%{_name}.so
%if 0%{?suse_version} < 1600
%dir %{_libdir}/tree_sitter
%endif

%treesitter_devel_package

%changelog
* Wed Dec  4 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.23.1:
  * ci(publish): add attestations and generate parser
  * build: update bindings
  * fix: remove unnecessary empty string usage
  * chore: regenerate
  * build: update bindings
  * ci: update workflows
  * fix(swift): include scanner.c
- update to 0.23.0:
  * build: update bindings
  * fix(go): correct test
  * fix: handle != operator definition
  * feat: support element references with blocks
  * fix: do not require newline after block comment =end
  * fix: parsing of multiple unicode escapes
  * fix: correct repo url
- update to 0.21.0:
  * ci: update workflows
  * feat: rewrite scanner with array header and regenerate
  * build: update bindings and manifests
  * fix: reverse precedence queries
  * fix: escape braces in regex
  * docs: update badges
- switch to download_files service
- add neovim links
- add license file to package
- remove 0001-fix-escape-braces-in-regex.patch as it got fixed upstream
- enable devel package
* Fri Mar 22 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Add patch from 0001-fix-escape-braces-in-regex.patch
  master branch to fix build against tree-sitter 0.22.x
* Mon Feb 26 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Initial packaging for openSUSE
- Update to version 0.20.1:
  * chore: update workflows and manifests
  * fix: emulated targets don't zero out stack variables
  * fix(build): change scanner name
  * refactor!: rewrite the scanner in C
  * chore: regenerate with tree-sitter-cli master
  * Fix 'case' with newlines before expression
  * Update node-gyp to 10 to fix compatibility with Python 3.12
